==> cloud-4.2.0.tar.gz: cloud/modules/cloud_dashboard/cloud_dashboard/src/constant/form_template/openstack/instance.ts <==
import EntityFormTemplate from 'model/EntityFormTemplate';

const OPENSTACK_INSTANCE_TEMPLATE: EntityFormTemplate[] = [
  {
    cloudServiceProvider: 'openstack',
    entityName: 'instance',
    actionType: 'edit',
    entityRecords: [
      {
        type: 'panel',
        panelName: 'Instance',
        keyValueRecords: [
          { type: 'default', labelName: 'Name', name: 'name', defaultValue: '', required: true },
          { labelName: 'Instance ID', name: 'instance_id', type: 'default', defaultValue: '', readOnly: true },
          { labelName: 'Instance State', name: 'instance_state', type: 'default', defaultValue: '', readOnly: true },
          { labelName: 'AMI Image', name: 'image_id', type: 'default', defaultValue: '', readOnly: true },
          { labelName: 'AWS account ID', name: 'account_id', type: 'default', defaultValue: '', readOnly: true },
          { labelName: 'Launch Time', name: 'launch_time', type: 'datetime' },
          { labelName: 'Created', name: 'created', type: 'datetime' },
        ]
      },
      {
        type: 'panel',
        panelName: 'Network',
        keyValueRecords: [
          { labelName: 'Private IPs', name: 'private_ips', type: 'default', defaultValue: '', readOnly: true },
          { labelName: 'Public DNS', name: 'public_dns', type: 'default', defaultValue: '', readOnly: true },
          {
            labelName: 'Key pair name', name: 'key_pair_name', type: 'join', info: {
              entityTypeId: 'openstack_key_pair',
              keyColumn: 'key_pair_name',
            }, defaultValue: '', readOnly: true
          },
          { labelName: 'Security groups', name: 'security_groups', type: 'default', defaultValue: '', readOnly: true },
          { labelName: 'Availability Zone', name: 'availability_zone', type: 'default', defaultValue: '', readOnly: true },
        ]
      },
      {
        type: 'panel',
        panelName: 'Storage',
        keyValueRecords: [
          { labelName: 'Volume', name: 'block_devices', type: 'default', defaultValue: '', readOnly: true },
        ]
      },
      {
        type: 'panel',
        panelName: 'Tags',
        keyValueRecords: [
          {
            type: 'key-value', labelName: 'Tags', name: 'tags',
            defaultValue: []
          },
        ]
      }
    ]
  },
  {
    cloudServiceProvider: 'openstack',
    entityName: 'instance',
    actionType: 'delete',
    entityRecords: [
      {
        type: 'label',
        text: 'Are you sure you want to delete the {{name}} {{entityName}}?'
      },
    ],
    submitButtonLabel: 'Delete'
  },
  {
    cloudServiceProvider: 'openstack',
    entityName: 'instance',
    actionType: 'start',
    entityRecords: [
      {
        type: 'label',
        text: 'Are you sure you want to start the {{name}} {{entityName}}?'
      },
    ],
    submitButtonLabel: 'Start'
  },
  {
    cloudServiceProvider: 'openstack',
    entityName: 'instance',
    actionType: 'stop',
    entityRecords: [
      {
        type: 'label',
        text: 'Are you sure you want to stop the {{name}} {{entityName}}?'
      },
    ],
    submitButtonLabel: 'Stop'
  }
]

export default OPENSTACK_INSTANCE_TEMPLATE;

==> cloud-4.3.0.tar.gz: cloud/modules/cloud_dashboard/cloud_dashboard/src/constant/form_template/openstack/instance.ts <==
import EntityFormTemplate from 'model/EntityFormTemplate';

const OPENSTACK_INSTANCE_TEMPLATE: EntityFormTemplate[] = [
  {
    cloudServiceProvider: 'openstack',
    entityName: 'instance',
    actionType: 'edit',
    entityRecords: [
      {
        type: 'panel',
        panelName: 'Instance',
        keyValueRecords: [
          { type: 'default', labelName: 'Name', name: 'name', defaultValue: '', required: true },
          { labelName: 'Instance ID', name: 'instance_id', type: 'default', defaultValue: '', readOnly: true },
          { labelName: 'Instance State', name: 'instance_state', type: 'default', defaultValue: '', readOnly: true },
          { labelName: 'AMI Image', name: 'image_id', type: 'default', defaultValue: '', readOnly: true },
          { labelName: 'AWS account ID', name: 'account_id', type: 'default', defaultValue: '', readOnly: true },
          { labelName: 'Launch Time', name: 'launch_time', type: 'datetime', defaultValue: 0, readOnly: true },
          { labelName: 'Created', name: 'created', type: 'datetime', defaultValue: 0, readOnly: true },
        ]
      },
      {
        type: 'panel',
        panelName: 'Network',
        keyValueRecords: [
          { labelName: 'Private IPs', name: 'private_ips', type: 'default', defaultValue: '', readOnly: true },
          { labelName: 'Public DNS', name: 'public_dns', type: 'default', defaultValue: '', readOnly: true },
          {
            labelName: 'Key pair name', name: 'key_pair_name', type: 'join', info: {
              entityTypeId: 'openstack_key_pair',
              keyColumn: 'key_pair_name',
            }, defaultValue: '', readOnly: true
          },
          { labelName: 'Security groups', name: 'security_groups', type: 'default', defaultValue: '', readOnly: true },
          { labelName: 'Availability Zone', name: 'availability_zone', type: 'default', defaultValue: '', readOnly: true },
        ]
      },
      {
        type: 'panel',
        panelName: 'Storage',
        keyValueRecords: [
          { labelName: 'Volume', name: 'block_devices', type: 'default', defaultValue: '', readOnly: true },
        ]
      },
      {
        type: 'panel',
        panelName: 'Tags',
        keyValueRecords: [
          {
            type: 'key-value', labelName: 'Tags', name: 'tags',
            defaultValue: []
          },
        ]
      }
    ]
  },
  {
    cloudServiceProvider: 'openstack',
    entityName: 'instance',
    actionType: 'delete',
    entityRecords: [
      {
        type: 'label',
        text: 'Are you sure you want to delete the {{name}} {{entityName}}?'
      },
    ],
    submitButtonLabel: 'Delete'
  },
  {
    cloudServiceProvider: 'openstack',
    entityName: 'instance',
    actionType: 'start',
    entityRecords: [
      {
        type: 'label',
        text: 'Are you sure you want to start the {{name}} {{entityName}}?'
      },
    ],
    submitButtonLabel: 'Start'
  },
  {
    cloudServiceProvider: 'openstack',
    entityName: 'instance',
    actionType: 'stop',
    entityRecords: [
      {
        type: 'label',
        text: 'Are you sure you want to stop the {{name}} {{entityName}}?'
      },
    ],
    submitButtonLabel: 'Stop'
  }
]

export default OPENSTACK_INSTANCE_TEMPLATE;
